#! /bin/sh

echo

scriptRoot=`echo $0 | sed -e 's,[/][^/]*$,,'`

perf2rrd_root="/opt/perf2rrd"
daemontool=1
systemd=1
mode="nagios"
mon_cmd=""
socket=""
rrd_socket=""

while getopts d:r:ts opt
do
	case "$opt" in
		d)      perf2rrd_root="$OPTARG";;
		t)      daemontool=0;;
		s)      systemd=0;;
		r)	rrd_socket="RRDCACHED_ADDRESS=\"$OPTARG\"";;
		*)      exit 2;
esac
done


echo "This script will perform a basic install of perf2rrd"

echo "Using $perf2rrd_root as perf2rrd_root"

mkdir -p $perf2rrd_root

echo "Copying Files..."
chmod ug+x $scriptRoot/compile
chmod ug+x $scriptRoot/run
chmod ug+x $scriptRoot/log/run

cp -rf $scriptRoot/* $perf2rrd_root/

cp -f $scriptRoot/configs/perf2rrd /etc/sysconfig/
sed -i "s,PERF2RRD_ROOT=.*,PERF2RRD_ROOT=\"$perf2rrd_root\",g" /etc/sysconfig/perf2rrd
sed -i "s,#INSTALL_RRDCACHED_ADDRESS.*,$rrd_socket,g" /etc/sysconfig/perf2rrd


if [ -d /etc/systemd/system ] && [ $systemd -eq 1 ]; then
	echo "Creating Systemd Startup Script"
	cp -f $scriptRoot/configs/perf2rrd.service /etc/systemd/system/
	sed -i "s,/bin/java,`which java`,g" /etc/systemd/system/perf2rrd.service  # fix path to java if needed 
	systemctl enable perf2rrd
	daemontool=0
fi

if [ -d /service ] && [ $daemontool -eq 1 ]; then
	echo "Creating Daemontools Link"
	ln -s $perf2rrd_root /service/
fi

if [ -d /etc/icinga2/features-available ]; then
	echo "Setting up Icinga2 configurations"
	cp -f $scriptRoot/configs/perf2rrd.conf /etc/icinga2/features-available/
	icinga2-enable-feature perf2rrd
	if [[ ! $(grep "object LivestatusListener.*socket_type.*tcp" /etc/icinga2/features-available/livestatus.conf) ]]; then 
		echo "Configuring and Enabling Livestatus TCP Socket"
		echo 'object LivestatusListener "livestatus-tcp" { socket_type = "tcp" }' >> /etc/icinga2/features-available/livestatus.conf
		icinga2-enable-feature livestatus
	fi

	mode="icinga2"
	mon_cmd="-n icinga2"
	socket="-l 127.0.0.1:6558"
fi

if [ -d /etc/icinga ]; then
	mode="icinga"
	mon_cmd="icinga"
fi

sed -i "s/#INSTALL_OPTIONS/OPTIONS/g" /etc/sysconfig/perf2rrd
sed -i "s/MON_CMD/$mon_cmd/g" /etc/sysconfig/perf2rrd
sed -i "s/LIVE_SOCKET/$socket/g" /etc/sysconfig/perf2rrd

echo "Done"

if [ "$mode" == "nagios" ] || [ "$mode" == "icinga" ]; then

cat <<VERBATIM

-----------------------------------------------------

Quick start...

copy:

define command {
        command_name perf2rrd
        command_line $perf2rrd_root/run -o
}

Into your Nagios/Icinga objects configuration.

In Main Config, set these variables


service_perfdata_file=/var/log/nagios/perfdata.pipe
service_perfdata_file_template=[SERVICEPERFDATA]\\t\$TIMET\$\\t\$HOSTNAME\$\\t\$SERVICEDESC\$\\t\$SERVICEEXECUTIONTIME\$\\t\$SERVICELATENCY\$\\t\$SERVICEOUTPUT\$\\t\$SERVICEPERFDATA\$
service_perfdata_file_mode=a
service_perfdata_file_processing_command=perf2rrd
service_perfdata_file_processing_interval=10

See $perf2rrd_root/doc/README for more advanced usage instructions.

VERBATIM

else

cat <<VERBATIM

Quick start:

If using Icinga2 on a systemd managed server, most configuration should be ready to go after a standard install.

Restart Icinga2

systemctl restart icinga2

Restart perf2rrd

systemctl restart perf2rrd

Verify that rrd files appear in /var/log/icinga2/rrd/

See $perf2rrd_root/doc/README for more advanced usage instructions.


VERBATIM

fi
